风之谷 (豆瓣)
Description: 风之谷电影简介和剧情介绍,风之谷影评、图片、预告片、影讯、论坛、在线购票
Keywords: 风之谷,風の谷のナウシカ,风之谷影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.172豆瓣电影Top250

# 风之谷 風の谷のナウシカ (1984)

导演: 宫崎骏
编剧: 宫崎骏
主演: 岛本须美 / 松田洋治 / 榊原良子 / 辻村真人 / 京田尚子 / 纳谷悟朗 / 永井一郎 / 宫内幸平 / 八奈见乘儿 / 矢田稔 / 富永美伊奈 / 家弓家正 / 吉田理保子 / 菅谷政子 / 坂本千夏 / 鳕子 / 麦人 / 大塚芳忠
类型: 动画 / 奇幻 / 冒险
制片国家/地区: 日本
语言: 日语
上映日期: 1992-05(中国大陆) / 1984-03-11(日本)
片长: 117分钟
又名: 风谷少女 / Kaze no tani no Naushika / Nausicaä of the Valley of the Wind
IMDb: tt0087544
豆瓣评分
引用
8.9
340295人评价
5星
54.8%
4星
35.8%
3星
8.7%
2星
0.5%
1星
0.2%
好于 97% 动画片
好于 98% 奇幻片
想看 看过
评价:
推荐

## 风之谷的剧情简介 · · · · · ·

工业文明的高度发展，却最终带来灾难，一场为期7天的虫族毁灭战争摧毁了人类文明。一千年后，工业文明遗留下来的症结仍在困扰这个星球。带有强烈毒性的植物组成了令人望而却步的“腐海”森林，随着时间的推移，腐海有条不紊地向四周蔓延，蚕食周边世界。在一片腐海森林的旁边，居住着一群御风而行的人类。女主角娜乌茜卡和族人依靠海风的力量抵御着有毒孢子的侵蚀，过着平静祥和的生活。
直到某一天，战火烧到了这里。西方强国特洛梅意欲重新建立人类霸权，他们计划统一周边诸国，然后向虫族发起总攻。另一方面，一千年前曾主导摧毁人类的上古怪兽“猛怪”重现人间。毁灭战争一触即发，人类的命运将会如何……
本片根据宫崎骏同名漫画改编，并分获1985年罗马奇幻电影节和1985年电影旬报最佳影片奖、1985年每日电影大藤信郎奖。 ©豆瓣

## 风之谷的演职员 · · · · · · ( 全部 48 )

- 宫崎骏 导演
- 岛本须美 配 娜乌西卡 ナウシカ Nausicaä
- 松田洋治 配 阿斯贝鲁 Asbel
- 榊原良子 配 库夏娜 クシャナ Kushana
- 辻村真人 配 基尔 ジル Jihl / Muzu
- 京田尚子 配 老婆婆 大ババ Oh-Baba

## 风之谷的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片639 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  幽灵公主

  天空之城

  红猪

  魔女宅急便

  哈尔的移动城堡

  猫的报恩

  大闹天宫

  百变狸猫

  哪吒闹海

  起风了

我要写短评

## 风之谷的短评 · · · · · · ( 全部 52205 条 )

热门 / 最新 / 好友

### 490 有用 莫呼洛迦-屁股上的青春在歌唱 看过 2010-10-01 22:24:20

〔三刷〕宮崎駿真是早早就把這個世界看透了。人類中心主義，容不得自己定義為「不好」的物種，即便這些物種只是因為人類的傲慢和愚蠢誤解了牠們；國家沙文主義不斷地通過殺戮和戰爭來擴張自己的版圖和思想，哪怕侵略和佔有這些領土只是為了滿足自己的虛榮心、要付出慘痛的代價，也在所不惜。我想來想去都想不明白，人類社會發展了幾百上千年，不論表現得再文明，骨子裡的傲慢和野蠻還是拿不掉，只是表現形式隨著科技的發展稍有不同... 〔三刷〕宮崎駿真是早早就把這個世界看透了。人類中心主義，容不得自己定義為「不好」的物種，即便這些物種只是因為人類的傲慢和愚蠢誤解了牠們；國家沙文主義不斷地通過殺戮和戰爭來擴張自己的版圖和思想，哪怕侵略和佔有這些領土只是為了滿足自己的虛榮心、要付出慘痛的代價，也在所不惜。我想來想去都想不明白，人類社會發展了幾百上千年，不論表現得再文明，骨子裡的傲慢和野蠻還是拿不掉，只是表現形式隨著科技的發展稍有不同。這真的令人感到難過。 (展开)

### 532 有用 蕊蕊 看过 2008-08-03 12:07:06

宫崎骏的主角为什么都是女生==

### 1340 有用 恶魔的步调 看过 2009-12-13 09:35:09

在此我们可以见到比卡丘的渊源，可以看到Spike飞船的渊源，可以看到虫师的渊源，也可以看到诸多动画人因此崛起的渊源。

### 22 有用 李和百万幽魂 看过 2007-02-09 11:15:28

好像大二夏天看得，那天晚上，看完以后差点被陌生人迷奸

### 913 有用 寂地 看过 2006-01-02 14:58:47

当女主角在黄金之海上复活的时候,我那发达的泪腺又西里哗啦了..

> 更多短评 52205条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 风之谷的影评 · · · · · · ( 全部 574 条 )

热门 / 最新 / 好友
russell 2005-09-25 22:03:39

## 一部年龄越大越喜欢的作品

建议先看电影，再看漫画，不然会有很大的落差感．因为漫画的思想层次比电影要高出许多，而且电影把许多人物都给省去或是简化了，显得没有漫画中那么丰满． 比如帝国的公主，在电影里就被描写成了纯粹的野心家，一心只想着利用巨神兵统治世界．但在漫画里却是个性格复杂的人物，... (展开)
1063 80 145回应 收起
恶魔的步调 2009-12-15 12:54:37

## 押井守与宫崎骏的战争

“其实押井守和高中生的宫崎骏有很多相似之处，他们的相遇成了很大的契机，改变了自己的战场，从此在同一个战场上共同战斗，因此在不同的方面可以发挥自己的力量，在此期间形成了自己的创作特色。”（铃木敏夫） 无论我们所叙述的这一对中心人物是否真的带有一点丑小鸭式的自卑... (展开)
584 54 96回应 收起
草纹 2007-07-12 17:18:54

## 《风之谷》随笔

无意中翻出动画片《风之谷》复习起来，这部宫崎骏导演的成名作可以称为是他后来所导演的一系列作品的引子。 七日之火与工业文明 记得看过的一个电视采访：日本第一位宇航员秋山丰宽（1990年乘坐原苏联航天飞机进入太空）在太空旅行结束后不久，便从大众的视线中消失了。他来到... (展开)
587 21 99回应 收起
短腿蘑菇 2008-08-25 20:22:44

## 能看宫崎俊的动画就是幸福

又一次被宫崎骏的动画感动到的一塌糊涂。前几看了《哈尔的移动城堡》、《猫的报恩》《天空之城》┅一次又一次被他的作品惊到。我不停的想象，那个总是爱用女孩做主角的男人在生活里是一个什么样的人，到底是什么赋予了他那么惊奇的想象力，如洪水般波涛汹涌，如雨露般永不... (展开)
310 24 102回应 收起
武志红 2008-05-12 09:20:29

## 我的丁克主义

想做丁克一族。 不是因为不喜欢孩子，而是因为赞同宫崎骏在《风之谷》中表达的观点：人类，是地球的害虫！ 周日，又看了一遍《风之谷》，当看到娜乌西卡“身着蓝衣，行走在金黄色的大草原”时，忍不住流下泪来。 娜乌西卡以一颗单纯的心发现了她置身的世界的奥... (展开)
225 93 136回应 收起
微風 2015-07-07 17:25:47

## 娜乌西卡

宫崎骏笔下的人物都十分令我喜爱 . 其中我一直最爱娜乌西卡!! 她是深具悲悯,善良,真诚,智慧与勇气的女孩 剧情是设定在曾经是世界产业文明颠峰时期，经历过＂火之七日＂的战争所演变出来的世界，之后世界就有了菌、大型昆虫，并且被腐海的新生态所掩盖，人类在新的环境的求生存... (展开)
62 1 5回应 收起
谢之艾 2015-05-06 14:53:02

## 神作！漫画与动画版的区别

这篇影评可能有剧透

神作！ 伟大的神作！10分！ 其内核也是人与自然和谐相处，但竟然比《幽灵公主》还要棒！（《幽灵公主》已经非常棒了！） ＝＝＝＝＝＝ 剧情简介： 1000年后的人们，并不是生活在天堂里，而看上去美丽的景象，其实是危机四伏。在人类自我毁灭的浩劫后，以菌类为主的腐海森林... (展开)
120 11回应 收起
Crazy Apollo 2007-07-24 20:06:56

## 风之谷诸神———之三，森林人

森林人的设定可以说是《风之谷》中的一个亮点。人究竟可以怎样活着？我们的欲望到底有多大？怎样才能满足？自古以来，这些问题一直，困扰着各个世代的无数人们。似乎没有人能够回答这些问题。 森林人的出场有7次，最早是在犹巴一行被僧会追杀，飞船被击落时，正当驯虫师们要... (展开)
89 7 21回应 收起
橙曦羽潞 2017-07-16 19:58:47

## 宫崎骏传递的环保理念

这部动画片主要讲述了：在人间多少年后，人类把所有的树木森林毁坏了，而有一个地方名叫腐海，它散发出种种有毒气体，里面所生存的植物都不是一般的植物，而且也都散发着毒气，最多的是那种毒性很强的孢子，它只要一分钟就可以毁灭生长了一百多年的森林。在这个地方，有许许多... (展开)
59 4 0回应 收起
美神经 2017-07-20 23:19:59

## 风之谷

娜乌西卡，一个16岁的小女孩，相比于大人，更具有独特的美好品格，关爱生命温柔聪敏。认为生命不在乎长短，在乎感受喜怒哀乐，享受自由追求自由。 王虫，拥有心灵沟通的能力，伸出的金色触须可以感受到对方的内心世界，并拥有治愈恢复的能力。其实它们是性情温顺的吧，但发怒时... (展开)
54 1 0回应 收起

> 更多影评 574篇

添加新讨论

## 讨论区 · · · · · ·

劝架的小细节（对比《幽灵公主》） | 来自巫马子 | 1 回应 | 2022-11-21 23:01:37
看这里，正确答案 | 来自蓝星笔记本 | 1 回应 | 2022-11-21 22:53:01
人类一千多年都没研究出树木可以净化污染吗？ | 来自带头大哥 | 3 回应 | 2022-11-21 22:30:24
为啥宫崎骏作品中大多数主角都是女孩 | 来自10点半的飞机 | 37 回应 | 2022-11-21 16:34:43
王虫吃什么能长这么大？ | 来自大旭 | 1 回应 | 2022-11-21 16:33:45

> 去这部影片的讨论区（全部107条）

## 关于《风之谷》的问题 · · · · · · ( 全部12个 )

- “细节：解开那个女孩衣服的时候看到了什么？”？ 8人回答
- 和王虫的交流后娜西乌卡问的“那个人还活着”是什么意思？ 6人回答

> 全部12个问题

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)
- 日本动画推荐 (恶魔的步调)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 沉默是最好的
  刚刚 看过
- 我会如何离开？
  2分钟前 看过
- 想不出来呀
  8分钟前 想看

679782人看过 / 211524人想看

订阅风之谷的评论:
feed: rss 2.0